@@ -1,7 +1,7 @@
 __import__("pkg_resources").declare_namespace(__name__)
 
 from logging import getLogger
-from pkg_resources import resource_filename
+from pkg_resources import resource_string
 
 logger = getLogger(__name__)
 
@@ -14,46 +14,35 @@ def generate_guid():
 
 ID_INVALID_PATTERN = r"[^A-Za-z0-9_\.]"
 ID_INVALID_PREFIX_PETTERN = r"^[^a-z_]"
-WIX_TEMPLATE = resource_filename(__name__, 'template.wxs')
+WIX_TEMPLATE = resource_string(__name__, 'template.wxs')
 BYPASS_CUSTOM_ACTION_PROPERTY = "NO_CUSTOM_ACTIONS"
 
-def read_template():
-    import lxml.etree
-    with open(WIX_TEMPLATE) as fd:
-        return lxml.etree.fromstring(fd.read())
 
 class Wix(object):
-    def __init__(self, product_name, product_version, architecture, upgrade_code, description, company_name):
+    def __init__(self, product_name, product_version, architecture, upgrade_code, description, company_name, documentation_url=None):
         super(Wix, self).__init__()
+        self._context = dict(
+            product_name=product_name,
+            product_version='.'.join(product_version.split('.')[:3]), # MSI supports a three-part version number format
+            architecture=architecture,
+            upgrade_code=upgrade_code,
+            description=description,
+            company_name=company_name,
+            documentation_url=documentation_url
+        )
+        xml = self._render_template()
+        self._content = self._parse_xml(xml)
         self._used_ids = set()
-        self._content = read_template()
-        self._inject_company_name(company_name)
-        self._inject_product_properties(product_name, product_version, architecture, upgrade_code, description)
-        self._architecture = architecture
         self._shortcuts_component = None
 
-    def _inject_company_name(self, company_name):
-        self.product.set("Manufacturer", company_name)
-        self.package.set("Manufacturer", company_name)
-        self.company_root_directory.set("Name", company_name)
-        self.company_program_menu_folder.set('Name', company_name)
+    def _render_template(self):
+        from jinja2 import Template, StrictUndefined
+        template = Template(WIX_TEMPLATE, undefined=StrictUndefined)
+        return template.render(self._context)
 
-    def _inject_product_properties(self, product_name, product_version, architecture, upgrade_code, description):
-        # Product
-        self.product.set('Name', product_name)
-        # MSI supports a three-part version number format
-        self.product.set('Version', '.'.join(product_version.split('.')[:3]))
-        self.product.set('UpgradeCode', upgrade_code)
-        # Package
-        self.package.set('InstallScope', 'perMachine')
-        self.package.set('Description', description)
-        # ProgramFiles
-        is64 = architecture == 'x64'
-        self.programfiles.set('Id', 'ProgramFiles64Folder' if is64 else 'ProgramFilesFolder')
-        # InstallDir
-        self.installdir.set('Name', product_name)
-        # Startmenu application folder
-        self.application_program_menu_folder.set('Name', product_name)
+    def _parse_xml(self, xml):
+        import lxml.etree
+        return lxml.etree.fromstring(xml)
 
     def _safe_id(self, unsafe_id):
         from re import sub
@@ -164,7 +153,8 @@ class Wix(object):
     def add_deferred_in_system_context_custom_action(self, name, cmd_line, fail_on_error=True,
                                                       cwd_dir=r'"[INSTALLDIR]"',
                                                       after='PublishProduct', before=None, condition=None,
-                                                      silent_launcher_file_id=None):
+                                                      silent_launcher_file_id=None,
+                                                      text=None):
         attributes = {'Id': self.new_id('custom_action_{}'.format(name)),
                       'FileKey': silent_launcher_file_id,
                       'ExeCommand': '{} {}'.format(cwd_dir, cmd_line),
@@ -181,6 +171,8 @@ class Wix(object):
         if condition is not None:
             sequence.text = '({}) AND (NOT {}="1")'.format(condition, BYPASS_CUSTOM_ACTION_PROPERTY) + \
                             (sequence.text or '')
+        if text is not None:
+            self.new_element("ProgressText", {"Action": action.get('Id')}, self.ui).text = text
         return action
 
     def get_shortcuts_component(self):
@@ -234,6 +226,35 @@ class Wix(object):
             if element.tag.endswith("Property") and element.get("Id") == name:
                 return element
 
+    def add_existing_install_dir(self, root, key, name):
+        # http://stackoverflow.com/questions/12576807/how-to-set-targetdir-or-installdir-from-a-registry-entry
+        element = self.new_element("Property", {"Id":"EXISTINGINSTALLDIR"}, self.product)
+        search_key = self.new_element("RegistrySearch", {"Id": "Locate_EXISTINGINSTALLDIR", "Root": root,
+                                                         "Key": key, "Name": name, "Type": "directory"}, element)
+        message = "Installation location in registry is missing: {}\\{}\\{}".format(root, key, name)
+        condition = self.new_element("Condition", {'Message': message}, self.product)
+        condition.text = "EXISTINGINSTALLDIR"
+
+    def set_custom_install_dir(self, value):
+        # http://stackoverflow.com/questions/12576807/how-to-set-targetdir-or-installdir-from-a-registry-entry
+        attributes = {'Id': "Set_INSTALLDIR", "Execute": "firstSequence", "Property": "INSTALLDIR", "Value": value}
+        action = self.new_element("CustomAction", attributes, self.product)
+        attributes = {"Action": action.get('Id')}
+        sequence = self.new_element("Custom", {"Action": action.get('Id'), "After": "FileCost"}, self.install_execute_sequence)
+        sequence.text = "(NOT Installed) AND (EXISTINGINSTALLDIR) AND (NOT UPGRADINGPRODUCTCODE)"
+        sequence = self.new_element("Custom", {"Action": action.get('Id'), "After": "FileCost"}, self.install_ui_sequence)
+        sequence.text = "(NOT Installed) AND (EXISTINGINSTALLDIR) AND (NOT UPGRADINGPRODUCTCODE)"
+
+    def prevent_user_from_choosing_installation_directory(self):
+        next = {"Dialog": "WelcomeDlg", "Control":"Next", "Event": "NewDialog", "Value": "InstallDirDlg"}
+        previous = {"Dialog": "VerifyReadyDlg", "Control":"Back", "Event": "NewDialog", "Value": "InstallDirDlg"}
+        for item in self.ui.iterchildren():
+            if item.tag.endswith("Publish"):
+                if all(item.attrib.get(key) == value for key, value in next.iteritems()):
+                    item.attrib["Value"] = "VerifyReadyDlg"
+                elif all(item.attrib.get(key) == value for key, value in previous.iteritems()):
+                    item.attrib["Value"] = "WelcomeDlg"
+
     def set_msi_property(self, key, value):
         element = self.get_msi_property(key)
         if element is None:
@@ -254,6 +275,14 @@ class Wix(object):
     def product(self):
         return self._content[0]
 
+    @property
+    def fragment(self):
+        return self._content[1]
+
+    @property
+    def ui(self):
+        return self.fragment[0]
+
     @property
     def package(self):
         return self.product[0]
@@ -292,13 +321,17 @@ class Wix(object):
 
     @property
     def install_execute_sequence(self):
-        return self.product[5]
+        return self.product[6]
+
+    @property
+    def install_ui_sequence(self):
+        return self.product[7]
 
     def build(self, wix_basedir, input_file, output_file):
         from ...utils.execute import execute_assert_success
         from os import path
         candle = path.join(wix_basedir, "candle.exe")
         light = path.join(wix_basedir, "light.exe")
-        execute_assert_success([candle, input_file, '-arch', self._architecture])
-        execute_assert_success([light, '-sval', '-ext', 'WixUIExtension', '-cultures:en-us',
+        execute_assert_success([candle, input_file, '-arch', self._context['architecture']])
+        execute_assert_success([light, '-sval', '-ext', 'WixUIExtension', '-ext', 'WixUtilExtension', '-cultures:en-us',
                                'product.wixobj', '-o', output_file])
